"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditFrame = void 0;
const vue_1 = require("vue");
const editing_1 = require("@sitecore-jss/sitecore-jss/editing");
exports.EditFrame = (0, vue_1.defineComponent)({
    props: {
        dataSource: { type: Object, default: undefined },
        buttons: {
            type: Object,
            default: undefined,
        },
        title: { type: String, default: undefined },
        tooltip: { type: String, default: undefined },
        cssClass: { type: String, default: undefined },
        parameters: {
            type: Object,
            default: undefined,
        },
        context: {
            type: Object,
            default: undefined,
        },
        routeData: {
            type: Object,
            default: undefined,
        },
    },
    render() {
        var _a, _b, _c;
        const instance = (0, vue_1.getCurrentInstance)();
        const children = this.$slots.default;
        // similar to placeholder implementation, try reading context locally first before retrieving it from global
        const sitecoreContext = this.$props.context || ((_a = instance.appContext.config.globalProperties.$jss) === null || _a === void 0 ? void 0 : _a.sitecoreContext());
        if (!sitecoreContext.pageEditing) {
            if (children) {
                return children();
            }
            return '';
        }
        const chromeData = {
            displayName: this.$props.title,
            expandedDisplayName: this.$props.tooltip,
        };
        const frameProps = {};
        frameProps.class = 'scLooseFrameZone';
        if (this.$props.cssClass) {
            frameProps.class = `${frameProps.class} ${this.$props.cssClass}`;
        }
        // item uri for edit frame target
        if (this.$props.dataSource) {
            const route = this.$props.routeData || ((_b = instance.appContext.config.globalProperties.$jss) === null || _b === void 0 ? void 0 : _b.routeData());
            const databaseName = this.$props.dataSource.databaseName || (route === null || route === void 0 ? void 0 : route.databaseName);
            const language = this.$props.dataSource.language || sitecoreContext.language;
            frameProps.sc_item = `sitecore://${databaseName}/${this.$props.dataSource.itemId}?lang=${language}`;
            chromeData.contextItemUri = frameProps.sc_item;
        }
        chromeData.commands = (_c = this.$props.buttons) === null || _c === void 0 ? void 0 : _c.map((value) => {
            var _a;
            return (0, editing_1.mapButtonToCommand)(value, (_a = this.$props.dataSource) === null || _a === void 0 ? void 0 : _a.itemId, this.$props.parameters);
        });
        if (children) {
            const childElements = (0, vue_1.h)('div', null, children());
            const chromeSpan = (0, vue_1.h)('span', {
                class: 'scChromeData',
                innerHTML: JSON.stringify(chromeData),
            });
            return (0, vue_1.h)('div', frameProps, [chromeSpan, childElements]);
        }
        else {
            const chromeSpan = (0, vue_1.h)('span', {
                class: 'scChromeData',
                innerHTML: JSON.stringify(chromeData),
            });
            return (0, vue_1.h)('div', frameProps, [chromeSpan]);
        }
    },
});
